package
Version:
v0.3.7
Opens a new window with list of versions in this module.
Published: Mar 13, 2026
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package outputs provides GitHub Actions output and logging utilities.
LogEndGroup ends a collapsible group.
LogError prints an error message.
LogGroup starts a collapsible group.
LogInfo prints an info message.
LogWarning prints a warning message.
func SetOutput(name, value string)
SetOutput writes a value to GITHUB_OUTPUT.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.